@@ -8,6 +8,12 @@ test_that("geocode works", {
   # Load package example data
   data(poi)
 
+  # Input checks
+  expect_error(geocode(c(1, 2, 3)), "'addresses' must be a 'character' vector.")
+  expect_error(geocode(c("character", NA)), "'addresses' contains NAs.")
+  expect_error(geocode(c("")), "'addresses' contains empty strings.")
+  expect_error(geocode(c("  ")), "'addresses' contains empty strings.")
+
   # Test with API response mock
   with_mock(
     "hereR:::.get_content" = function(url) {hereR:::mock$geocode_response},
